#!/bin/bash

minversion="10.4.1"
CWROOT="/usr/local/curbywall"
BIN="/usr/sbin"
LDROOT="/Library/LaunchDaemons"
CONFROOT="/etc"
execfiles="curbywall ipfw-status"
inertfiles="ipfw.conf local-sample.conf routing-sample.conf shaping-sample.conf README COPYING"

# Usage: myinstall [prm [[own] grp]] src dst
myinstall() {
  case $# in
    2)  prm=755; own=$UID;            src=$1; dst=$2 ;;
    3)  prm=$1;  own=$UID;            src=$2; dst=$3 ;;
    4)  prm=$1;  own=$UID; grp=":$2"; src=$3; dst=$4 ;;
    5)  prm=$1;  own=$2;   grp=":$3"; src=$4; dst=$5 ;;
    *)  echo "Usage: myinstall [prm [own [grp]]] src dst"; exit 1;;
  esac

  cp -p $src $dst
  chmod $prm $dst/$src
  chown $own$grp $dst/$src
}

# Sanity check platform
if [[ "`sw_vers -productVersion`" < $minversion ]]; then
  echo "This firewall makes use of features new in OS X $minversion.  If you think you know better,"
  echo "disable this check or install the files manually."
  exit 1
fi

# Sanity check permissions
if [[ "$UID" != "0" ]]; then
  echo "You need to have root privileges to run this script."
  echo "You might try running 'sudo $0'."
  exit 2
fi

# Make curbywall directory
echo "Making $CWROOT directory..."
mkdir -p $CWROOT
chmod 755 $CWROOT

# Install curbywall files
echo -n "Installing files... "
for file in $execfiles; do
  echo -n "$file "
  myinstall 755 wheel "$file" $CWROOT
done

for file in $inertfiles; do
  echo -n "$file "
  myinstall 644 wheel "$file" $CWROOT
done
echo

# Install sysctl file
echo "Installing sysctl.conf..."
myinstall 644 sysctl.conf $CONFROOT

# Install LaunchDaemon
echo "Installing LaunchDaemon plist..."
myinstall 644 net.curby.Curbywall.plist $LDROOT

# Create symlinks
for file in $execfiles; do
  if [[ ! -e "$BIN/$file" ]]; then
    echo "Creating link to $file in $BIN"
    ln -s $CWROOT/$file $BIN/$file
  fi
done

# Enable logging both for reboots and now
echo "Enabling verbose logging..."
defaults write /Library/Preferences/com.apple.sharing.firewall loggingenabled -integer '1'
sysctl -w net.inet.ip.fw.verbose=2 > /dev/null

echo "Installation completed.  Run curbywall to initialize firewall."
